@@ -1,9 +1,7 @@
-import warnings
 import pathlib
-import importlib.util
 import configparser
 
-__version__ = '0.7.0'
+__version__ = '0.12.0'
 
 # Load the configuration settings.
 HERE = pathlib.Path(__file__).parent.resolve()
@@ -19,24 +17,31 @@ except KeyError:  # Raised if config.ini does not have Paths.
 config = {'ASILIB_DIR': HERE, 'ASI_DATA_DIR': ASI_DATA_DIR}
 
 # Import download programs.
-from asilib.io.download_rego import download_rego_img, download_rego_skymap
-from asilib.io.download_themis import download_themis_img, download_themis_skymap
+from asilib.io.download import download_image
+from asilib.io.download import download_skymap
 
 # Import the loading functions.
-from asilib.io.load import load_cal, load_skymap
-from asilib.io.load import get_frame
-from asilib.io.load import get_frames
+from asilib.io.load import load_skymap
+from asilib.io.load import load_image
+from asilib.io.load import load_image_generator
 
 # Import the plotting and animating functions.
-from asilib.plot.plot_frame import plot_frame
+from asilib.plot.plot_fisheye import plot_fisheye
 from asilib.plot.plot_map import plot_map
+from asilib.plot.plot_map import make_map
 from asilib.plot.plot_keogram import plot_keogram
-from asilib.plot.plot_movie import plot_movie, plot_movie_generator
+from asilib.plot.animate_fisheye import animate_fisheye
+from asilib.plot.animate_fisheye import animate_fisheye_generator
+from asilib.plot.animate_map import animate_map
+from asilib.plot.animate_map import animate_map_generator
 
 # Import the analysis functions.
-from asilib.analysis.map import lla2azel, lla2footprint, lla_to_skyfield, map_along_magnetic_field
+from asilib.analysis.map import lla2azel
+from asilib.analysis.map import lla2footprint
 from asilib.analysis.keogram import keogram
 from asilib.analysis.equal_area import equal_area
 
-# Import the equal_area function.
-from asilib.analysis.equal_area import equal_area
+# Imager implementation functions and classes.
+from asilib.imager import Imager
+from asilib.conjunction import Conjunction
+from asilib.array.themis import themis, themis_info
